==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Inscribed_areas/group__PkgInscribedAreasRef.js <==
var group__PkgInscribedAreasRef =
[
    [ "Concepts", "group__PkgInscribedAreasConcepts.html", "group__PkgInscribedAreasConcepts" ],
    [ "Extremal_polygon_area_traits_2", "structCGAL_1_1Extremal__polygon__area__traits__2.html", [
      [ "FT", "structCGAL_1_1Extremal__polygon__area__traits__2.html#a07b4ca56a81da52d72675f4526e2bca8", null ],
      [ "Less_xy_2", "structCGAL_1_1Extremal__polygon__area__traits__2.html#aab0f0cfdf4f103d8f7cda870e44a348d", null ],
      [ "Operation", "structCGAL_1_1Extremal__polygon__area__traits__2.html#a16c6c91adaa1449918fe002fb0a6bb94", null ],
      [ "Orientation_2", "structCGAL_1_1Extremal__polygon__area__traits__2.html#abb273756d586d6626463e557066977d3", null ],
      [ "Point_2", "structCGAL_1_1Extremal__polygon__area__traits__2.html#afde3ec21c37098fff1bc523cc2cbacc1", null ],
      [ "compute_min_k_gon", "structCGAL_1_1Extremal__polygon__area__traits__2.html#a6ba7355c8c07011c0592b761d914c70e", null ],
      [ "init", "structCGAL_1_1Extremal__polygon__area__traits__2.html#ac9179b0ae9895d374667a9b5cdc7d3f6", null ],
      [ "less_xy_2_object", "structCGAL_1_1Extremal__polygon__area__traits__2.html#abdc3e0c0af07049a0f2ab74868acc4ae", null ],
      [ "min_k", "structCGAL_1_1Extremal__polygon__area__traits__2.html#ab150ef867dbb4c5b9c8534eba676b7bf", null ],
      [ "operation", "structCGAL_1_1Extremal__polygon__area__traits__2.html#a3ff8aab49df343b1031fb02d2d3b91cc", null ],
      [ "orientation_2_object", "structCGAL_1_1Extremal__polygon__area__traits__2.html#ad5a16ea6bbba40a730aebe333d3c3103", null ]
    ] ],
    [ "Extremal_polygon_perimeter_traits_2", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html", [
      [ "FT", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#a8e6b53d0164ecb36910e32e94c9bdb90", null ],
      [ "Less_xy_2", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#a285382d78ddb3a55fd30845db09e4727", null ],
      [ "Operation", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#a8356d0bbdf7416496b159c2a576d1816", null ],
      [ "Orientation_2", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#a85c9be9887bc743381b16bf4856cb65d", null ],
      [ "Point_2", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#afc413a61d1db0569a7056fd456ca13c9", null ],
      [ "compute_min_k_gon", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#a6c97c1a1edc3c7db016e8331e94cff28", null ],
      [ "init", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#aacfef1ca7a51e022ffbac7e5029f2c7c", null ],
      [ "less_xy_2_object", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#afde445a6197ac7ca8a01649313baee08", null ],
      [ "min_k", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#a41d6c13974ab7d7d80f1fbff6db5c229", null ],
      [ "operation", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#a462d3b8b6d853bb2e98e9007f8c9d685", null ],
      [ "orientation_2_object", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#aee9f45a5ffdba7d31758edac1dc0daa1", null ]
    ] ],
    [ "Largest_empty_iso_rectangle_2", "classCGAL_1_1Largest__empty__iso__rectangle__2.html", [
      [ "const_iterator", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a537250091f61d0bee317a1cefb94d20e", null ],
      [ "Iso_rectangle_2", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a7b9b519d4236aa2826f3353954d5b6a1", null ],
      [ "Point_2", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a54d5285983096586c012455ed58e9f4f", null ],
      [ "Largest_empty_iso_rectangle_2", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a07d9a42edfad79245176725d895b4c72", null ],
      [ "Largest_empty_iso_rectangle_2", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#aeb6512309e27bbf55190cf95736f0395", null ],
      [ "Largest_empty_iso_rectangle_2", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a7b82da827ef76c771739b54f2092f326", null ],
      [ "Largest_empty_iso_rectangle_2", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a6d60ee6be028c9fbdff917df97fbf5a2", null ],
      [ "begin", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a373dee8b12f849c0977fd56eed618a19", null ],
      [ "clear", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#aada179160e0332b9fca4e9b8c52ae448", null ],
      [ "end", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a89d76e45299f04558e6bf597045c2177", null ],
      [ "get_bounding_box", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a1ae96ff54a4a69f3a17f108c3660cff6", null ],
      [ "get_largest_empty_iso_rectangle", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a9ebceb08ad9ab5a8d917093f29e6d90a", null ],
      [ "get_left_bottom_right_top", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a6d5b90adc77aebff86e18bab9ae07156", null ],
      [ "insert", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a3661a064cd4359ce6db8a7516518b8fa", null ],
      [ "insert", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a0bfc0714aa07b40db1e4338db58ef35d", null ],
      [ "operator=", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a3848108e64fab295ce2e3d15a818faf0", null ],
      [ "push_back", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a1b2a92b25793e790220222f775e294dd", null ],
      [ "remove", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a290c5e2931268650f17b2dfdea6fdade", null ],
      [ "traits", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a0889d3203a9b8155f0ae127a88c57762", null ]
    ] ],
    [ "extremal_polygon_2", "group__PkgInscribedAreasRef.html#ga6ae7d07c984fededc523e252beb643eb", null ],
    [ "maximum_area_inscribed_k_gon_2", "group__PkgInscribedAreasRef.html#gadc80e01bb74bc8b33fb22c1e31364e0f", null ],
    [ "maximum_perimeter_inscribed_k_gon_2", "group__PkgInscribedAreasRef.html#ga7051f3ca755d0a5d64b42422e99046a6", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Inscribed_areas/group__PkgInscribedAreasRef.js <==
var group__PkgInscribedAreasRef =
[
    [ "Concepts", "group__PkgInscribedAreasConcepts.html", "group__PkgInscribedAreasConcepts" ],
    [ "CGAL::Extremal_polygon_area_traits_2< K >", "structCGAL_1_1Extremal__polygon__area__traits__2.html", [
      [ "FT", "structCGAL_1_1Extremal__polygon__area__traits__2.html#a07b4ca56a81da52d72675f4526e2bca8", null ],
      [ "Less_xy_2", "structCGAL_1_1Extremal__polygon__area__traits__2.html#aab0f0cfdf4f103d8f7cda870e44a348d", null ],
      [ "Operation", "structCGAL_1_1Extremal__polygon__area__traits__2.html#a16c6c91adaa1449918fe002fb0a6bb94", null ],
      [ "Orientation_2", "structCGAL_1_1Extremal__polygon__area__traits__2.html#abb273756d586d6626463e557066977d3", null ],
      [ "Point_2", "structCGAL_1_1Extremal__polygon__area__traits__2.html#afde3ec21c37098fff1bc523cc2cbacc1", null ],
      [ "compute_min_k_gon", "structCGAL_1_1Extremal__polygon__area__traits__2.html#a6ba7355c8c07011c0592b761d914c70e", null ],
      [ "init", "structCGAL_1_1Extremal__polygon__area__traits__2.html#ac9179b0ae9895d374667a9b5cdc7d3f6", null ],
      [ "less_xy_2_object", "structCGAL_1_1Extremal__polygon__area__traits__2.html#abdc3e0c0af07049a0f2ab74868acc4ae", null ],
      [ "min_k", "structCGAL_1_1Extremal__polygon__area__traits__2.html#ab150ef867dbb4c5b9c8534eba676b7bf", null ],
      [ "operation", "structCGAL_1_1Extremal__polygon__area__traits__2.html#a3ff8aab49df343b1031fb02d2d3b91cc", null ],
      [ "orientation_2_object", "structCGAL_1_1Extremal__polygon__area__traits__2.html#ad5a16ea6bbba40a730aebe333d3c3103", null ]
    ] ],
    [ "CGAL::Extremal_polygon_perimeter_traits_2< K >", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html", [
      [ "FT", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#a8e6b53d0164ecb36910e32e94c9bdb90", null ],
      [ "Less_xy_2", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#a285382d78ddb3a55fd30845db09e4727", null ],
      [ "Operation", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#a8356d0bbdf7416496b159c2a576d1816", null ],
      [ "Orientation_2", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#a85c9be9887bc743381b16bf4856cb65d", null ],
      [ "Point_2", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#afc413a61d1db0569a7056fd456ca13c9", null ],
      [ "compute_min_k_gon", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#a6c97c1a1edc3c7db016e8331e94cff28", null ],
      [ "init", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#aacfef1ca7a51e022ffbac7e5029f2c7c", null ],
      [ "less_xy_2_object", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#afde445a6197ac7ca8a01649313baee08", null ],
      [ "min_k", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#a41d6c13974ab7d7d80f1fbff6db5c229", null ],
      [ "operation", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#a462d3b8b6d853bb2e98e9007f8c9d685", null ],
      [ "orientation_2_object", "structCGAL_1_1Extremal__polygon__perimeter__traits__2.html#aee9f45a5ffdba7d31758edac1dc0daa1", null ]
    ] ],
    [ "CGAL::Largest_empty_iso_rectangle_2< T >", "classCGAL_1_1Largest__empty__iso__rectangle__2.html", [
      [ "const_iterator", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a537250091f61d0bee317a1cefb94d20e", null ],
      [ "Iso_rectangle_2", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a7b9b519d4236aa2826f3353954d5b6a1", null ],
      [ "Point_2", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a54d5285983096586c012455ed58e9f4f", null ],
      [ "Largest_empty_iso_rectangle_2", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a07d9a42edfad79245176725d895b4c72", null ],
      [ "Largest_empty_iso_rectangle_2", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#aeb6512309e27bbf55190cf95736f0395", null ],
      [ "Largest_empty_iso_rectangle_2", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a7b82da827ef76c771739b54f2092f326", null ],
      [ "Largest_empty_iso_rectangle_2", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a6d60ee6be028c9fbdff917df97fbf5a2", null ],
      [ "begin", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a373dee8b12f849c0977fd56eed618a19", null ],
      [ "clear", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#aada179160e0332b9fca4e9b8c52ae448", null ],
      [ "end", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a89d76e45299f04558e6bf597045c2177", null ],
      [ "get_bounding_box", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a1ae96ff54a4a69f3a17f108c3660cff6", null ],
      [ "get_largest_empty_iso_rectangle", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a9ebceb08ad9ab5a8d917093f29e6d90a", null ],
      [ "get_left_bottom_right_top", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#afcb687db1f2701d8bc38923a9f325134", null ],
      [ "insert", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a3661a064cd4359ce6db8a7516518b8fa", null ],
      [ "insert", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a0bfc0714aa07b40db1e4338db58ef35d", null ],
      [ "operator=", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#aaa5faf9163580869fe03315f430d24d2", null ],
      [ "push_back", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a1b2a92b25793e790220222f775e294dd", null ],
      [ "remove", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#a290c5e2931268650f17b2dfdea6fdade", null ],
      [ "traits", "classCGAL_1_1Largest__empty__iso__rectangle__2.html#ac3f0f32479c48c0cae12b8cdbdd4b007", null ]
    ] ],
    [ "CGAL::extremal_polygon_2", "group__PkgInscribedAreasRef.html#ga6ae7d07c984fededc523e252beb643eb", null ],
    [ "CGAL::maximum_area_inscribed_k_gon_2", "group__PkgInscribedAreasRef.html#gadc80e01bb74bc8b33fb22c1e31364e0f", null ],
    [ "CGAL::maximum_perimeter_inscribed_k_gon_2", "group__PkgInscribedAreasRef.html#ga7051f3ca755d0a5d64b42422e99046a6", null ]
];
